@@ -5,16 +5,17 @@ import os
 import pathlib
 import pickle
 import shutil
+import subprocess
 from collections import UserDict
 from dataclasses import dataclass
 from hashlib import blake2b
 from operator import attrgetter
+from os.path import join as pjoin
 
 from snakeoil import klass
 from snakeoil.compatibility import IGNORED_EXCEPTIONS
 from snakeoil.fileutils import AtomicWriteFile
 from snakeoil.mappings import ImmutableDict
-from snakeoil.osutils import pjoin
 
 from ..base import Addon, PkgcheckException, PkgcheckUserException
 from ..log import logger
@@ -23,6 +24,7 @@ from ..log import logger
 @dataclass(frozen=True)
 class CacheData:
     """Cache registry data."""
+
     type: str
     file: str
     version: int
@@ -31,7 +33,7 @@ class CacheData:
 class Cache:
     """Mixin for data caches."""
 
-    __getattr__ = klass.GetAttrProxy('_cache')
+    __getattr__ = klass.GetAttrProxy("_cache")
 
 
 class DictCache(UserDict, Cache):
@@ -46,7 +48,7 @@ class CacheDisabled(PkgcheckException):
     """Exception flagging that a requested cache type is disabled."""
 
     def __init__(self, cache):
-        super().__init__(f'{cache.type} cache support required')
+        super().__init__(f"{cache.type} cache support required")
 
 
 class CachedAddon(Addon):
@@ -61,7 +63,7 @@ class CachedAddon(Addon):
         """Register available caches."""
         super().__init_subclass__(**kwargs)
         if cls.cache is None:
-            raise ValueError(f'invalid cache registry: {cls!r}')
+            raise ValueError(f"invalid cache registry: {cls!r}")
         cls.caches[cls] = cls.cache
 
     def update_cache(self, repo=None, force=False):
@@ -75,17 +77,26 @@ class CachedAddon(Addon):
         using the same identifier don't use the same cache file.
         """
         token = blake2b(repo.location.encode()).hexdigest()[:10]
-        dirname = f'{repo.repo_id.lstrip(os.sep)}-{token}'
-        return pjoin(self.options.cache_dir, 'repos', dirname, self.cache.file)
+        dirname = f"{repo.repo_id.lstrip(os.sep)}-{token}"
+        return pjoin(self.options.cache_dir, "repos", dirname, self.cache.file)
 
-    def load_cache(self, path, fallback=None):
+    def load_cache(self, path: str, fallback=None):
         cache = fallback
         try:
-            with open(path, 'rb') as f:
-                cache = pickle.load(f)
+            if path.endswith(".zst"):
+                if not os.path.exists(path):
+                    raise FileNotFoundError(path)
+                with subprocess.Popen(("zstd", "-qdcf", path), stdout=subprocess.PIPE) as proc:
+                    if proc.poll():
+                        raise PkgcheckUserException(
+                            f"failed decompressing {self.cache.type} cache: {path!r}"
+                        )
+                    cache = pickle.load(proc.stdout)
+            else:
+                with open(path, "rb") as f:
+                    cache = pickle.load(f)
             if cache.version != self.cache.version:
-                logger.debug(
-                    'forcing %s cache regen due to outdated version', self.cache.type)
+                logger.debug("forcing %s cache regen due to outdated version", self.cache.type)
                 os.remove(path)
                 cache = fallback
         except IGNORED_EXCEPTIONS:
@@ -93,28 +104,34 @@ class CachedAddon(Addon):
         except FileNotFoundError:
             pass
         except Exception as e:
-            logger.debug('forcing %s cache regen: %s', self.cache.type, e)
+            logger.debug("forcing %s cache regen: %s", self.cache.type, e)
             os.remove(path)
             cache = fallback
         return cache
 
-    def save_cache(self, data, path):
+    def save_cache(self, data, path: str):
         try:
             os.makedirs(os.path.dirname(path), exist_ok=True)
-            with AtomicWriteFile(path, binary=True) as f:
-                pickle.dump(data, f, protocol=-1)
+            if path.endswith(".zst"):
+                with subprocess.Popen(("zstd", "-T0", "-fqo", path), stdin=subprocess.PIPE) as proc:
+                    pickle.dump(data, proc.stdin, protocol=-1)
+                if os.path.exists(path[:-4]):
+                    logger.warning("removing old %s cache file", self.cache.type)
+                    os.remove(path[:-4])
+            else:
+                with AtomicWriteFile(path, binary=True) as f:
+                    pickle.dump(data, f, protocol=-1)
         except IOError as e:
-            msg = f'failed dumping {self.cache.type} cache: {path!r}: {e.strerror}'
+            msg = f"failed dumping {self.cache.type} cache: {path!r}: {e.strerror}"
             raise PkgcheckUserException(msg)
 
     @klass.jit_attr
     def existing_caches(self):
         """Mapping of all existing cache types to file paths."""
         caches_map = {}
-        repos_dir = pjoin(self.options.cache_dir, 'repos')
-        for cache in sorted(self.caches.values(), key=attrgetter('type')):
-            caches_map[cache.type] = tuple(sorted(
-                pathlib.Path(repos_dir).rglob(cache.file)))
+        repos_dir = pjoin(self.options.cache_dir, "repos")
+        for cache in sorted(self.caches.values(), key=attrgetter("type")):
+            caches_map[cache.type] = tuple(sorted(pathlib.Path(repos_dir).rglob(cache.file)))
         return ImmutableDict(caches_map)
 
     def remove_caches(self):
@@ -125,14 +142,14 @@ class CachedAddon(Addon):
             except FileNotFoundError:
                 pass
             except IOError as e:
-                raise PkgcheckUserException(f'failed removing cache dir: {e}')
+                raise PkgcheckUserException(f"failed removing cache dir: {e}")
         else:
             try:
                 for cache_type, paths in self.existing_caches.items():
                     if self.options.cache.get(cache_type, False):
                         for path in paths:
                             if self.options.dry_run:
-                                print(f'Would remove {path}')
+                                print(f"Would remove {path}")
                             else:
                                 os.unlink(path)
                                 # remove empty cache dirs
@@ -145,4 +162,4 @@ class CachedAddon(Addon):
                                         continue
                                     raise
             except IOError as e:
-                raise PkgcheckUserException(f'failed removing {cache_type} cache: {path!r}: {e}')
+                raise PkgcheckUserException(f"failed removing {cache_type} cache: {path!r}: {e}")
