@@ -4,12 +4,15 @@ from difflib import SequenceMatcher
 from itertools import chain
 
 from pkgcore import fetch
+from pkgcore.ebuild.digest import Manifest
 from snakeoil.sequences import iflatten_instance
 from snakeoil.strings import pluralism
 
 from .. import addons, base, results, sources
 from . import Check, MirrorsCheck, RepoCheck
 
+DEPRECATED_HASHES = frozenset({"md5", "rmd160", "sha1", "whirlpool"})
+
 
 class MultiMovePackageUpdate(results.ProfilesResult, results.Warning):
     """Entry for package moved multiple times in profiles/updates files."""
@@ -79,11 +82,16 @@ class PackageUpdatesCheck(RepoCheck):
     """Scan profiles/updates/* for outdated entries and other issues."""
 
     _source = (sources.EmptySource, (base.profiles_scope,))
-    known_results = frozenset([
-        MultiMovePackageUpdate, OldMultiMovePackageUpdate,
-        OldPackageUpdate, MovedPackageUpdate, BadPackageUpdate,
-        RedundantPackageUpdate,
-    ])
+    known_results = frozenset(
+        {
+            MultiMovePackageUpdate,
+            OldMultiMovePackageUpdate,
+            OldPackageUpdate,
+            MovedPackageUpdate,
+            BadPackageUpdate,
+            RedundantPackageUpdate,
+        }
+    )
 
     def __init__(self, *args):
         super().__init__(*args)
@@ -92,10 +100,12 @@ class PackageUpdatesCheck(RepoCheck):
 
     def finish(self):
         logmap = (
-            base.LogMap('pkgcore.log.logger.warning', MovedPackageUpdate),
-            base.LogMap('pkgcore.log.logger.error', BadPackageUpdate),
+            base.LogMap("pkgcore.log.logger.warning", MovedPackageUpdate),
+            base.LogMap("pkgcore.log.logger.error", BadPackageUpdate),
         )
 
+        if hasattr(self.repo.config, "_updates"):
+            del self.repo.config.__dict__["_updates"]  # clear cache for immutable dict
         # convert log warnings/errors into reports
         with base.LogReports(*logmap) as log_reports:
             repo_updates = self.repo.config.updates
@@ -106,8 +116,8 @@ class PackageUpdatesCheck(RepoCheck):
         old_slotmove_updates = {}
 
         for pkg, updates in repo_updates.items():
-            move_updates = [x for x in updates if x[0] == 'move']
-            slotmove_updates = [x for x in updates if x[0] == 'slotmove']
+            move_updates = [x for x in updates if x[0] == "move"]
+            slotmove_updates = [x for x in updates if x[0] == "slotmove"]
 
             # check for multi-updates, a -> b, b -> c, ...
             if len(move_updates) > 1:
@@ -126,7 +136,7 @@ class PackageUpdatesCheck(RepoCheck):
             # scan updates for old entries with removed packages
             for x in slotmove_updates:
                 _, pkg, newslot = x
-                orig_line = ('slotmove', str(pkg)[:-(len(pkg.slot) + 1)], pkg.slot, newslot)
+                orig_line = ("slotmove", str(pkg)[: -(len(pkg.slot) + 1)], pkg.slot, newslot)
                 if not self.search_repo.match(pkg.unversioned_atom):
                     # reproduce updates file line data for result output
                     old_slotmove_updates[pkg.key] = orig_line
@@ -160,15 +170,15 @@ class UnusedLicenses(results.Warning):
     @property
     def desc(self):
         s = pluralism(self.licenses)
-        licenses = ', '.join(self.licenses)
-        return f'unused license{s}: {licenses}'
+        licenses = ", ".join(self.licenses)
+        return f"unused license{s}: {licenses}"
 
 
 class UnusedLicensesCheck(RepoCheck):
     """Check for unused license files."""
 
     _source = sources.RepositoryRepoSource
-    known_results = frozenset([UnusedLicenses])
+    known_results = frozenset({UnusedLicenses})
 
     def __init__(self, *args):
         super().__init__(*args)
@@ -199,15 +209,15 @@ class UnusedMirrors(results.Warning):
     @property
     def desc(self):
         s = pluralism(self.mirrors)
-        mirrors = ', '.join(self.mirrors)
-        return f'unused mirror{s}: {mirrors}'
+        mirrors = ", ".join(self.mirrors)
+        return f"unused mirror{s}: {mirrors}"
 
 
 class UnusedMirrorsCheck(MirrorsCheck, RepoCheck):
     """Check for unused mirrors."""
 
     _source = sources.RepositoryRepoSource
-    known_results = frozenset([UnusedMirrors])
+    known_results = frozenset({UnusedMirrors})
 
     def start(self):
         master_mirrors = set()
@@ -234,16 +244,16 @@ class UnusedEclasses(results.Warning):
 
     @property
     def desc(self):
-        es = pluralism(self.eclasses, plural='es')
-        eclasses = ', '.join(self.eclasses)
-        return f'unused eclass{es}: {eclasses}'
+        es = pluralism(self.eclasses, plural="es")
+        eclasses = ", ".join(self.eclasses)
+        return f"unused eclass{es}: {eclasses}"
 
 
 class UnusedEclassesCheck(RepoCheck):
     """Check for unused eclasses."""
 
     _source = sources.RepositoryRepoSource
-    known_results = frozenset([UnusedEclasses])
+    known_results = frozenset({UnusedEclasses})
 
     def __init__(self, *args):
         super().__init__(*args)
@@ -253,8 +263,9 @@ class UnusedEclassesCheck(RepoCheck):
         master_eclasses = set()
         for repo in self.options.target_repo.masters:
             master_eclasses.update(repo.eclass_cache.eclasses.keys())
-        self.unused_eclasses = set(
-            self.options.target_repo.eclass_cache.eclasses.keys()) - master_eclasses
+        self.unused_eclasses = (
+            set(self.options.target_repo.eclass_cache.eclasses.keys()) - master_eclasses
+        )
 
     def feed(self, pkg):
         self.unused_eclasses.difference_update(pkg.inherited)
@@ -276,15 +287,15 @@ class UnknownLicenses(results.Warning):
     @property
     def desc(self):
         s = pluralism(self.licenses)
-        licenses = ', '.join(self.licenses)
-        return f'license group {self.group!r} has unknown license{s}: [ {licenses} ]'
+        licenses = ", ".join(self.licenses)
+        return f"license group {self.group!r} has unknown license{s}: [ {licenses} ]"
 
 
 class LicenseGroupsCheck(RepoCheck):
     """Scan license groups for unknown licenses."""
 
     _source = (sources.EmptySource, (base.repo_scope,))
-    known_results = frozenset([UnknownLicenses])
+    known_results = frozenset({UnknownLicenses})
 
     def __init__(self, *args):
         super().__init__(*args)
@@ -307,10 +318,10 @@ class PotentialLocalUse(results.Info):
     @property
     def desc(self):
         s = pluralism(self.pkgs)
-        pkgs = ', '.join(self.pkgs)
+        pkgs = ", ".join(self.pkgs)
         return (
-            f'global USE flag {self.flag!r} is a potential local, '
-            f'used by {len(self.pkgs)} package{s}: {pkgs}'
+            f"global USE flag {self.flag!r} is a potential local, "
+            f"used by {len(self.pkgs)} package{s}: {pkgs}"
         )
 
 
@@ -324,8 +335,8 @@ class UnusedGlobalUse(results.Warning):
     @property
     def desc(self):
         s = pluralism(self.flags)
-        flags = ', '.join(self.flags)
-        return f'use.desc unused flag{s}: {flags}'
+        flags = ", ".join(self.flags)
+        return f"use.desc unused flag{s}: {flags}"
 
 
 class UnusedGlobalUseExpand(results.Warning):
@@ -338,8 +349,8 @@ class UnusedGlobalUseExpand(results.Warning):
     @property
     def desc(self):
         s = pluralism(self.flags)
-        flags = ', '.join(self.flags)
-        return f'unused flag{s}: {flags}'
+        flags = ", ".join(self.flags)
+        return f"unused flag{s}: {flags}"
 
 
 class PotentialGlobalUse(results.Info):
@@ -354,7 +365,8 @@ class PotentialGlobalUse(results.Info):
     def desc(self):
         return (
             f"local USE flag {self.flag!r} is a potential global "
-            f"used by {len(self.pkgs)} packages: {', '.join(self.pkgs)}")
+            f"used by {len(self.pkgs)} packages: {', '.join(self.pkgs)}"
+        )
 
 
 def _dfs(graph, start, visited=None):
@@ -369,13 +381,17 @@ def _dfs(graph, start, visited=None):
 class GlobalUseCheck(RepoCheck):
     """Check global USE and USE_EXPAND flags for various issues."""
 
-    _source = (sources.RepositoryRepoSource, (), (('source', sources.PackageRepoSource),))
-    required_addons = (addons.UseAddon,)
-    known_results = frozenset([
-        PotentialLocalUse, PotentialGlobalUse, UnusedGlobalUse, UnusedGlobalUseExpand,
-    ])
+    _source = (sources.RepositoryRepoSource, (), (("source", sources.PackageRepoSource),))
+    known_results = frozenset(
+        {
+            PotentialLocalUse,
+            PotentialGlobalUse,
+            UnusedGlobalUse,
+            UnusedGlobalUseExpand,
+        }
+    )
 
-    def __init__(self, *args, use_addon):
+    def __init__(self, *args):
         super().__init__(*args)
         self.global_flag_usage = defaultdict(set)
         self.repo = self.options.target_repo
@@ -393,8 +409,8 @@ class GlobalUseCheck(RepoCheck):
         """Yield groups of packages with similar local USE flag descriptions."""
         # calculate USE flag description difference ratios
         diffs = {}
-        for i, (i_pkg, i_desc) in enumerate(pkgs):
-            for j, (j_pkg, j_desc) in enumerate(pkgs[i + 1:]):
+        for i, (_i_pkg, i_desc) in enumerate(pkgs):
+            for j, (_j_pkg, j_desc) in enumerate(pkgs[i + 1 :]):
                 diffs[(i, i + j + 1)] = SequenceMatcher(None, i_desc, j_desc).ratio()
 
         # create an adjacency list using all closely matching flags pairs
@@ -424,11 +440,12 @@ class GlobalUseCheck(RepoCheck):
                 yield [pkgs[i][0] for i in component]
 
     def finish(self):
-        repo_global_use = {
-            flag for matcher, (flag, desc) in self.repo.config.use_desc}
+        repo_global_use = {flag for matcher, (flag, desc) in self.repo.config.use_desc}
         repo_global_use_expand = {
-            flag for use_expand in self.repo.config.use_expand_desc.values()
-            for flag, desc in use_expand}
+            flag
+            for use_expand in self.repo.config.use_expand_desc.values()
+            for flag, desc in use_expand
+        }
         repo_local_use = self.repo.config.use_local_desc
         unused_global_use = []
         unused_global_use_expand = []
@@ -481,7 +498,8 @@ class MissingChksum(results.VersionResult, results.Warning):
     def desc(self):
         return (
             f"{self.filename!r} missing required chksums: "
-            f"{', '.join(self.missing)}; has chksums: {', '.join(self.existing)}")
+            f"{', '.join(self.missing)}; has chksums: {', '.join(self.existing)}"
+        )
 
 
 class DeprecatedChksum(results.VersionResult, results.Warning):
@@ -495,8 +513,8 @@ class DeprecatedChksum(results.VersionResult, results.Warning):
     @property
     def desc(self):
         s = pluralism(self.deprecated)
-        deprecated = ', '.join(self.deprecated)
-        return f'{self.filename!r} has deprecated checksum{s}: {deprecated}'
+        deprecated = ", ".join(self.deprecated)
+        return f"{self.filename!r} has deprecated checksum{s}: {deprecated}"
 
 
 class MissingManifest(results.VersionResult, results.Error):
@@ -509,8 +527,8 @@ class MissingManifest(results.VersionResult, results.Error):
     @property
     def desc(self):
         s = pluralism(self.files)
-        files = ', '.join(self.files)
-        return f'distfile{s} missing from Manifest: [ {files} ]'
+        files = ", ".join(self.files)
+        return f"distfile{s} missing from Manifest: [ {files} ]"
 
 
 class UnknownManifest(results.PackageResult, results.Warning):
@@ -523,8 +541,8 @@ class UnknownManifest(results.PackageResult, results.Warning):
     @property
     def desc(self):
         s = pluralism(self.files)
-        files = ', '.join(self.files)
-        return f'unknown distfile{s} in Manifest: [ {files} ]'
+        files = ", ".join(self.files)
+        return f"unknown distfile{s} in Manifest: [ {files} ]"
 
 
 class UnnecessaryManifest(results.PackageResult, results.Warning):
@@ -537,14 +555,31 @@ class UnnecessaryManifest(results.PackageResult, results.Warning):
     @property
     def desc(self):
         s = pluralism(self.files)
-        files = ', '.join(self.files)
-        return f'unnecessary file{s} in Manifest: [ {files} ]'
+        files = ", ".join(self.files)
+        return f"unnecessary file{s} in Manifest: [ {files} ]"
 
 
 class InvalidManifest(results.MetadataError, results.PackageResult):
     """Package's Manifest file is invalid."""
 
-    attr = 'manifest'
+    attr = "manifest"
+
+
+class DeprecatedManifestHash(results.PackageResult, results.Warning):
+    """Manifest uses deprecated hashes.
+
+    The package uses deprecated hash types in its Manifest file.
+    """
+
+    def __init__(self, hashes, **kwargs):
+        super().__init__(**kwargs)
+        self.hashes = tuple(hashes)
+
+    @property
+    def desc(self):
+        s = pluralism(self.hashes)
+        hashes = ", ".join(self.hashes)
+        return f"defines deprecated manifest hash types{s}: [ {hashes} ]"
 
 
 class ManifestCheck(Check):
@@ -556,29 +591,41 @@ class ManifestCheck(Check):
 
     required_addons = (addons.UseAddon,)
     _source = sources.PackageRepoSource
-    known_results = frozenset([
-        MissingChksum, MissingManifest, UnknownManifest, UnnecessaryManifest,
-        DeprecatedChksum, InvalidManifest,
-    ])
+    known_results = frozenset(
+        {
+            MissingChksum,
+            MissingManifest,
+            UnknownManifest,
+            UnnecessaryManifest,
+            DeprecatedChksum,
+            InvalidManifest,
+            DeprecatedManifestHash,
+        }
+    )
 
-    def __init__(self, *args, use_addon):
+    def __init__(self, *args, use_addon: addons.UseAddon):
         super().__init__(*args)
         repo = self.options.target_repo
         self.preferred_checksums = frozenset(
-            repo.config.manifests.hashes if hasattr(repo, 'config') else ())
+            repo.config.manifests.hashes if hasattr(repo, "config") else ()
+        )
         self.required_checksums = frozenset(
-            repo.config.manifests.required_hashes if hasattr(repo, 'config') else ())
-        self.iuse_filter = use_addon.get_filter('fetchables')
+            repo.config.manifests.required_hashes if hasattr(repo, "config") else ()
+        )
+        self.iuse_filter = use_addon.get_filter("fetchables")
 
     def feed(self, pkgset):
-        pkg_manifest = pkgset[0].manifest
+        pkg_manifest: Manifest = pkgset[0].manifest
+        pkg_manifest.allow_missing = True
         manifest_distfiles = set(pkg_manifest.distfiles.keys())
         seen = set()
         for pkg in pkgset:
             pkg.release_cached_data()
             fetchables, _ = self.iuse_filter(
-                (fetch.fetchable,), pkg,
-                pkg.generate_fetchables(allow_missing_checksums=True, ignore_unknown_mirrors=True))
+                (fetch.fetchable,),
+                pkg,
+                pkg.generate_fetchables(allow_missing_checksums=True, ignore_unknown_mirrors=True),
+            )
             fetchables = set(fetchables)
             pkg.release_cached_data()
 
@@ -593,24 +640,27 @@ class ManifestCheck(Check):
                 missing = self.required_checksums.difference(f_inst.chksums)
                 if f_inst.filename not in missing_manifests and missing:
                     yield MissingChksum(
-                        f_inst.filename, sorted(missing),
-                        sorted(f_inst.chksums), pkg=pkg)
-                elif f_inst.chksums and self.preferred_checksums != frozenset(f_inst.chksums):
-                    deprecated = set(f_inst.chksums).difference(self.preferred_checksums)
-                    yield DeprecatedChksum(f_inst.filename, sorted(deprecated), pkg=pkg)
+                        f_inst.filename, sorted(missing), sorted(f_inst.chksums), pkg=pkg
+                    )
+                elif f_inst.chksums:
+                    if deprecated := frozenset(f_inst.chksums).difference(self.preferred_checksums):
+                        yield DeprecatedChksum(f_inst.filename, sorted(deprecated), pkg=pkg)
                 seen.add(f_inst.filename)
 
         if pkg_manifest.thin:
-            unnecessary_manifests = []
-            for attr in ('aux_files', 'ebuilds', 'misc'):
-                unnecessary_manifests.extend(getattr(pkg_manifest, attr, []))
+            unnecessary_manifests = set()
+            for attr in ("aux_files", "ebuilds", "misc"):
+                unnecessary_manifests.update(getattr(pkg_manifest, attr, ()))
             if unnecessary_manifests:
                 yield UnnecessaryManifest(sorted(unnecessary_manifests), pkg=pkgset[0])
 
-        unknown_manifests = manifest_distfiles.difference(seen)
-        if unknown_manifests:
+        if unknown_manifests := manifest_distfiles.difference(seen):
             yield UnknownManifest(sorted(unknown_manifests), pkg=pkgset[0])
 
+        used_hashes = frozenset().union(*pkg_manifest.distfiles.values())
+        if deprecated_hashes := DEPRECATED_HASHES.intersection(used_hashes):
+            yield DeprecatedManifestHash(sorted(deprecated_hashes), pkg=pkgset[0])
+
 
 class ConflictingChksums(results.VersionResult, results.Error):
     """Checksum conflict detected between two files."""
@@ -624,12 +674,12 @@ class ConflictingChksums(results.VersionResult, results.Error):
     @property
     def desc(self):
         s = pluralism(self.chksums)
-        chksums = ', '.join(self.chksums)
+        chksums = ", ".join(self.chksums)
         pkgs_s = pluralism(self.pkgs)
-        pkgs = ', '.join(self.pkgs)
+        pkgs = ", ".join(self.pkgs)
         return (
-            f'distfile {self.filename!r} has different checksum{s} '
-            f'({chksums}) for package{pkgs_s}: {pkgs}'
+            f"distfile {self.filename!r} has different checksum{s} "
+            f"({chksums}) for package{pkgs_s}: {pkgs}"
         )
 
 
@@ -644,9 +694,9 @@ class MatchingChksums(results.VersionResult, results.Warning):
 
     @property
     def desc(self):
-        msg = f'distfile {self.filename!r} matches checksums for {self.orig_file!r}'
-        if f'{self.category}/{self.package}' != self.orig_pkg:
-            msg += f' from {self.orig_pkg}'
+        msg = f"distfile {self.filename!r} matches checksums for {self.orig_file!r}"
+        if f"{self.category}/{self.package}" != self.orig_pkg:
+            msg += f" from {self.orig_pkg}"
         return msg
 
 
@@ -657,23 +707,22 @@ class ManifestCollisionCheck(Check):
     different filenames with matching checksums.
     """
 
-    _source = (sources.RepositoryRepoSource, (), (('source', sources.PackageRepoSource),))
-    known_results = frozenset([ConflictingChksums, MatchingChksums])
+    _source = (sources.RepositoryRepoSource, (), (("source", sources.PackageRepoSource),))
+    known_results = frozenset({ConflictingChksums, MatchingChksums})
 
     def __init__(self, *args):
         super().__init__(*args)
         self.seen_files = {}
         self.seen_chksums = {}
         # ignore go.mod false positives (issue #228)
-        self._ignored_files_re = re.compile(r'^.*%2F@v.*\.mod$')
+        self._ignored_files_re = re.compile(r"^.*%2F@v.*\.mod$")
 
     def _conflicts(self, pkg):
         """Check for similarly named distfiles with different checksums."""
         for filename, chksums in pkg.manifest.distfiles.items():
             existing = self.seen_files.get(filename)
             if existing is None:
-                self.seen_files[filename] = (
-                    [pkg.key], dict(chksums.items()))
+                self.seen_files[filename] = ([pkg.key], dict(chksums.items()))
                 continue
             seen_pkgs, seen_chksums = existing
             conflicting_chksums = []
@@ -723,13 +772,45 @@ class ProjectMetadataCheck(RepoCheck):
     """Check projects.xml for issues."""
 
     _source = (sources.EmptySource, (base.repo_scope,))
-    known_results = frozenset([EmptyProject])
+    known_results = frozenset({EmptyProject})
 
     def __init__(self, *args):
         super().__init__(*args)
         self.repo = self.options.target_repo
 
     def finish(self):
-        for key, project in self.repo.projects_xml.projects.items():
+        for project in self.repo.projects_xml.projects.values():
             if not project.recursive_members:
                 yield EmptyProject(project)
+
+
+class DeprecatedRepoHash(results.Warning):
+    """Repositories ``manifest-hashes`` defines deprecated hashes.
+
+    The repository defines deprecated hashes in ``manifest-hashes``.
+    """
+
+    def __init__(self, hashes):
+        super().__init__()
+        self.hashes = tuple(hashes)
+
+    @property
+    def desc(self):
+        s = pluralism(self.hashes)
+        hashes = ", ".join(self.hashes)
+        return f"defines deprecated manifest-hash{s}: [ {hashes} ]"
+
+
+class RepoManifestHashCheck(RepoCheck):
+    """Check ``manifest-hashes`` config for issues."""
+
+    _source = (sources.EmptySource, (base.repo_scope,))
+    known_results = frozenset({DeprecatedRepoHash})
+
+    def __init__(self, *args):
+        super().__init__(*args)
+        self.repo = self.options.target_repo
+
+    def finish(self):
+        if deprecated_hashes := DEPRECATED_HASHES.intersection(self.repo.config.manifests.hashes):
+            yield DeprecatedRepoHash(sorted(deprecated_hashes))
