@@ -28,7 +28,7 @@ ci.add_argument(
 
 
 @ci.bind_main_func
-def _ci(options, out, err):
+def _ci(options, out: PlainTextFormatter, _err):
     pipe = scan(options.args)
 
     with reporters.FancyReporter(out) as reporter:
