@@ -1,22 +1,23 @@
 import os
 import subprocess
 from functools import partial
+from os.path import join as pjoin
 from unittest.mock import Mock, patch
 
 import pytest
-from pkgcheck import base
-from pkgcheck.addons import git, init_addon
-from pkgcheck.base import PkgcheckUserException
-from pkgcheck.addons.caches import CacheDisabled
 from pkgcore.ebuild.atom import MalformedAtom
 from pkgcore.ebuild.atom import atom as atom_cls
 from pkgcore.restrictions import packages
 from snakeoil.cli.exceptions import UserException
 from snakeoil.contexts import os_environ
 from snakeoil.fileutils import touch
-from snakeoil.osutils import pjoin
 from snakeoil.process import CommandNotFound, find_binary
 
+from pkgcheck import base
+from pkgcheck.addons import git, init_addon
+from pkgcheck.addons.caches import CacheDisabled
+from pkgcheck.base import PkgcheckUserException
+
 # skip testing module if git isn't installed
 try:
     find_binary("git")
