@@ -1,15 +1,16 @@
 import os
 from datetime import datetime, timedelta
+from os.path import join as pjoin
 
 import pytest
-from pkgcheck import addons
-from pkgcheck.checks import SkipCheck, pkgdir
 from pkgcore.ebuild.cpv import UnversionedCPV
 from pkgcore.test.misc import FakeRepo
-from snakeoil import fileutils
 from snakeoil.cli import arghparse
 from snakeoil.fileutils import touch
-from snakeoil.osutils import ensure_dirs, pjoin
+from snakeoil.osutils import ensure_dirs
+
+from pkgcheck import addons
+from pkgcheck.checks import SkipCheck, pkgdir
 
 from .. import misc
 
