@@ -1,11 +1,12 @@
 import os
 from datetime import datetime, timedelta
+from os.path import join as pjoin
 
 import pytest
+from pkgcore.ebuild.cpv import VersionedCPV
+
 from pkgcheck.checks import SkipCheck
 from pkgcheck.checks.stablereq import StableRequest, StableRequestCheck
-from pkgcore.ebuild.cpv import VersionedCPV
-from snakeoil.osutils import pjoin
 
 from ..misc import ReportTestCase, init_check
 
