@@ -1,28 +1,35 @@
+import importlib
+import importlib.machinery
+import io
 import os
+import pathlib
 import shlex
 import shutil
 import subprocess
-import tempfile
 import textwrap
+import typing
 from collections import defaultdict
+from contextlib import chdir
+from dataclasses import dataclass
 from functools import partial
 from io import StringIO
 from operator import attrgetter
+from os.path import join as pjoin
 from unittest.mock import patch
 
 import pytest
-from pkgcheck import __title__ as project
-from pkgcheck import base
-from pkgcheck import checks as checks_mod
-from pkgcheck import const, objects, reporters, scan
-from pkgcheck.scripts import run
 from pkgcore import const as pkgcore_const
 from pkgcore.ebuild import atom, restricts
 from pkgcore.restrictions import packages
-from snakeoil.contexts import chdir, os_environ
+from snakeoil.contexts import os_environ
 from snakeoil.fileutils import touch
 from snakeoil.formatters import PlainTextFormatter
-from snakeoil.osutils import pjoin
+
+from pkgcheck import __title__ as project
+from pkgcheck import base, const, objects, reporters, scan
+from pkgcheck import checks as checks_mod
+from pkgcheck.results import Result
+from pkgcheck.scripts import run
 
 from ..misc import Profile
 
@@ -587,69 +594,165 @@ class TestPkgcheckScan:
         assert len(results) == len(results_set)
         return results_set
 
-    def _get_results(self, path: str):
-        """Return the set of result objects from a given json stream file."""
-        try:
-            with (self.repos_data / path).open() as f:
-                return set(reporters.JsonStream.from_iter(f))
-        except FileNotFoundError:
-            return set()
+    @dataclass
+    class _expected_data_result:
+        expected: dict[Result, pathlib.Path]
+        expected_verbose: dict[Result, pathlib.Path]
+        custom_filter: typing.Callable[[Result], bool] | None
 
-    def _render_results(self, results, **kwargs):
+    def _load_expected_data(self, base: pathlib.Path) -> _expected_data_result:
+        """Return the set of result objects from a given json stream file."""
+
+        custom_handler = None
+        try:
+            with (custom_handler_path := base / "handler.py").open():
+                # We can't import since it's not a valid python directory layout, nor do
+                # want to pollute the namespace.
+                module = importlib.machinery.SourceFileLoader(
+                    "handler", str(custom_handler_path)
+                ).load_module()
+                if (
+                    custom_handler := typing.cast(
+                        typing.Callable[[Result], bool], getattr(module, "handler")
+                    )
+                ) is None:
+                    pytest.fail(
+                        f"custom python handler {custom_handler_path!r} lacks the necessary handle function or list of handlers"
+                    )
+
+                if not callable(custom_handler):
+                    pytest.fail(f"{custom_handler_path} handler isn't invokable")
+                custom_handler.__source_file__ = custom_handler_path  # pyright: ignore[reportFunctionMemberAccess]
+        except FileNotFoundError:
+            pass
+
+        def boilerplate(path, allow_missing: bool):
+            try:
+                with path.open() as f:
+                    data = list(reporters.JsonStream.from_iter(f))
+
+                    uniqued = set(data)
+                    duplicates = [
+                        x for x in data if (False, None) == (x in uniqued, uniqued.discard(x))
+                    ]
+                    assert [] == duplicates, f"duplicate results exist in {path!r}"
+
+                    # Remove this after cleaning the scan/fix logic up to not force duplicate
+                    # renders, and instead just work with a result stream directly.
+                    assert self._render_results(data), f"failed rendering results {data!r}"
+                    return typing.cast(dict[Result, pathlib.Path], {}.fromkeys(data, path))
+
+            except FileNotFoundError:
+                if not allow_missing:
+                    raise
+                return {}
+
+        expected_path = base / "expected.json"
+        # if a custom handler exists, then the json definitions aren't required.
+        expected = boilerplate(expected_path, custom_handler is not None)
+        if custom_handler is None:
+            assert expected, (
+                f"regular results must always exist if the file exists: {expected_path}"
+            )
+
+        expected_verbose_path = base / "expected-verbose.json"
+        expected_verbose = boilerplate(expected_verbose_path, True)
+
+        return self._expected_data_result(expected, expected_verbose, custom_handler)
+
+    def _render_results(self, results, **kwargs) -> str:
         """Render a given set of result objects into their related string form."""
-        with tempfile.TemporaryFile() as f:
+        with io.BytesIO() as f:
             with reporters.FancyReporter(out=PlainTextFormatter(f), **kwargs) as reporter:
                 for result in sorted(results):
                     reporter.report(result)
-            f.seek(0)
-            output = f.read().decode()
-            return output
+            return f.getvalue().decode()
 
     @pytest.mark.parametrize("repo", repos)
     def test_scan_repo(self, repo, tmp_path_factory):
         """Run pkgcheck against test pkgs in bundled repo, verifying result output."""
-        results = set()
-        verbose_results = set()
+
+        # _sources is so people debugging failures know where the testdata came from.  It matters in regards to devex.
+        expected_results_sources = {}
         scan_results = self._scan_results(repo, tmp_path_factory.mktemp("scan"), verbosity=0)
+
+        expected_verbose_results_sources = {}
         scan_verbose_results = self._scan_results(repo, tmp_path_factory.mktemp("ver"), verbosity=1)
+
+        custom_handlers: list[typing.Callable[[Result], bool]] = []
+
         for check, keywords in self._checks[repo].items():
             for keyword in keywords:
-                # verify the expected results were seen during the repo scans
-                expected_results = self._get_results(f"{repo}/{check}/{keyword}/expected.json")
-                assert expected_results, "regular results must always exist"
-                assert self._render_results(expected_results), "failed rendering results"
-                results.update(expected_results)
-
-                # when expected verbose results exist use them, otherwise fallback to using the regular ones
-                expected_verbose_results = self._get_results(
-                    f"{repo}/{check}/{keyword}/expected-verbose.json"
-                )
-                if expected_verbose_results:
-                    assert self._render_results(expected_verbose_results), (
-                        "failed rendering verbose results"
+                path = self.repos_data / repo / check / keyword
+                data = self._load_expected_data(path)
+                if conflict := {
+                    k: [v, expected_results_sources[k]]
+                    for k, v in data.expected.items()
+                    if k in expected_results_sources
+                }:
+                    pytest.fail(
+                        f"conflicting results found in testdata for the following fixtures: {conflict!r}"
                     )
-                    verbose_results.update(expected_verbose_results)
-                else:
-                    verbose_results.update(expected_results)
 
-        if results != scan_results:
-            missing = self._render_results(results - scan_results)
-            unknown = self._render_results(scan_results - results)
-            error = ["unmatched repo scan results:\n\n"]
-            if missing:
-                error.append(f"{repo} repo missing expected results:\n{missing}")
-            if unknown:
-                error.append(f"{repo} repo unknown results:\n{unknown}")
-            pytest.fail("\n".join(error), pytrace=False)
-        if verbose_results != scan_verbose_results:
-            missing = self._render_results(verbose_results - scan_verbose_results)
-            unknown = self._render_results(scan_verbose_results - verbose_results)
-            error = ["unmatched verbose repo scan results:\n\n"]
-            if missing:
-                error.append(f"{repo} repo missing expected results:\n{missing}")
-            if unknown:
-                error.append(f"{repo} repo unknown results:\n{unknown}")
-            pytest.fail("\n".join(error), pytrace=False)
+                expected_results_sources.update(data.expected)
+
+                if data.expected_verbose:
+                    expected_verbose_results_sources.update(data.expected_verbose)
+                else:
+                    expected_verbose_results_sources.update(data.expected)
+
+                if data.custom_filter is not None:
+                    custom_handlers.append(data.custom_filter)
+
+        for handler in custom_handlers:
+            try:
+                # sanity checks; both that they don't intersect expected results from other testdata,
+                # and also do the filtering.
+                for verbose_text, expected, actual in (
+                    ("", expected_results_sources, scan_results),
+                    ("verbose ", expected_verbose_results_sources, scan_verbose_results),
+                ):
+                    if intersection := list(filter(handler, expected)):
+                        pytest.fail(
+                            f"handler from {handler.__source_file__!r} incorrectly suppresses {verbose_text}test data: {intersection}"  # pyright: ignore[reportFunctionMemberAccess]
+                        )
+
+                    for k in list(filter(handler, actual)):
+                        actual.remove(k)
+
+            except Exception as e:
+                pytest.fail(
+                    f"handler {data.custom_filter.__source_file__!r} threw an exception: {e!r}"  # type: ignore
+                )
+
+        def assert_same(sources, results, verbose=False):
+            expected = set(sources)
+            errors = []
+            if missing := expected.difference(results):
+                lines = [
+                    f"from source: {sources[x]}, expected:\n{self._render_results([x])}"
+                    for x in missing
+                ]
+                errors.append("\n".join(lines))
+                for handler in custom_handlers:
+                    for result in missing:
+                        if handler(result):
+                            errors.append(
+                                f"possible cause: handler {handler.__source_file__} matches"  # pyright: ignore[reportFunctionMemberAccess]
+                            )
+
+            if unknown := results.difference(sources):
+                text = self._render_results(unknown)
+                errors.append(f"unknown results:\n{text}")
+
+            if errors:
+                verbose = "verbose " if verbose else ""
+                pytest.fail(
+                    f"repo {repo} {verbose}scan failures:\n" + "\n\n".join(errors), pytrace=False
+                )
+
+        assert_same(expected_results_sources, scan_results)
+        assert_same(expected_verbose_results_sources, scan_verbose_results, True)
 
     @staticmethod
     def _patch(fix, repo_path):
